import java.io.BufferedReader;
import java.io.File;
import java.io.IOException;
import java.io.InputStreamReader;
import java.util.List;
import java.util.Map;

import org.jboss.byteman.test.TestScript;

import com.google.common.collect.Lists;

/*
 * Wraps the byteman script compile tool so that it returns a CompilationResult object which can
 * more easily be used by the unitTest
 */
public class ScriptCompileToolWrapper {

    /*
     * Takes a file which points to the script to be compiled
     * 
     * Returns a Map of: -script rulenames -> CompilationResults for that rule
     */
    public static Map<String, CompilationResult> compileScript(File script) {

        Process theProcess = null;

        try {
            String classpath = System.getProperty("java.class.path");
            String toolClassname = TestScript.class.getName();

            String command = "java -classpath " + classpath + " " + toolClassname + " " +
                script.getAbsolutePath();
            System.out.println(command);
            theProcess = Runtime.getRuntime().exec(command);
        } catch (IOException e) {
            System.err.println("Error on exec() method");
            e.printStackTrace();
        }

        // read from the called program's standard output streams
        List<String> consoleOutLines = Lists.newArrayList();
        List<String> consoleErrorLines = Lists.newArrayList();
        try {
            BufferedReader outStream = new BufferedReader(new InputStreamReader(
                theProcess.getInputStream()));
            BufferedReader errStream = new BufferedReader(new InputStreamReader(
                theProcess.getErrorStream()));

            String line;
            while ((line = outStream.readLine()) != null) {
                consoleOutLines.add(line);
            }

            while ((line = errStream.readLine()) != null) {
                consoleErrorLines.add(line);
            }
        } catch (IOException e) {
            System.err.println("Error on inStream.readLine()");
            e.printStackTrace();
        }

        return ConsoleOutputScanner.scanConsoleOutput(consoleOutLines, consoleErrorLines);
    }

}
