import java.io.File;
import java.io.FilenameFilter;
import java.io.IOException;
import java.util.List;

import com.google.common.collect.Lists;

/*
 * Finds all the byteman instrumentation scripts which exist for this project
 */
public class ScriptDiscovery {

    public static final String INSTRUMENTATION_SCRIPT_FOLDER = "instrumentation/scripts";

    public static List<File> findScriptsForThisProject() throws IOException {
        File scriptDir = new File(INSTRUMENTATION_SCRIPT_FOLDER);
        if (!scriptDir.exists()) {
            throw new IOException("ScriptDiscovery: Cannot find directory = " +
                INSTRUMENTATION_SCRIPT_FOLDER + " for this project");
        }

        if (!scriptDir.isDirectory()) {
            throw new IOException("ScriptDiscovery: Cannot open " + INSTRUMENTATION_SCRIPT_FOLDER +
                ", it is not directory for this project.");
        }

        FilenameFilter bytemanScriptFilter = new FilenameFilter() {
            // accept any file of the form
            // *.btm
            // examples
            // vanillaIRSPricer.btm
            @Override
            public boolean accept(File dir, String name) {
                return name.matches(".*\\.btm");
            }
        };

        File[] curveStructFiles = scriptDir.listFiles(bytemanScriptFilter);
        return Lists.newArrayList(curveStructFiles);
    }
}
